@@ -8,16 +8,21 @@ from requests.exceptions import HTTPError
 
 class APIRequest:
     def _api_key_checker(api_key=None):
+        api_key_error_message = "Please specify a valid api_key or create one here:\n https://console.api.audio"
         PLACEHOLDERS = ["your-key", "APIKEY", "API_KEY"]
         if api_key == None or api_key in PLACEHOLDERS:
             # aflr_key is for backward compatibility with the old name of env vars.
-            api_key = os.environ.get("apiaudio_key", os.environ.get("aflr_key", None))
+            api_key = os.environ.get("apiaudio_key", os.environ.get("aflr_key"))
+
+            if api_key == None:
+                raise TypeError(f"No api_key has been found. {api_key_error_message}")
+
         if not isinstance(api_key, str):
             raise TypeError("api_key must be of type string.")
 
         if len(api_key) < 32:
             raise ValueError(
-                "Please specify a valid api_key or create one here:\n https://console.api.audio"
+                f"api_key has less than 32 characters. {api_key_error_message}"
             )
         apiaudio.api_key = api_key
         return
@@ -58,6 +63,9 @@ class APIRequest:
 
     @classmethod
     def _download_request(cls, url, destination):
+        if type(url) is not str:
+            raise TypeError("Error retrieving the audio files.")
+
         local_filename = f"{destination}/{url.split('/')[-1].split('?')[0]}"
         local_filename = local_filename.replace("%243ct10n", "section")
 
