@@ -24,10 +24,10 @@ class RetrievableResource(APIRequest):
 
         if section:
             params.update({"section": section})
-        
+
         if public is not None:
             params.update({"public": public})
-        
+
         if vast is not None:
             params.update({"vast": vast})
 
@@ -42,7 +42,15 @@ class RetrievableResource(APIRequest):
 
 class DownloadableResource(APIRequest):
     @classmethod
-    def download(cls, scriptId, section=None, parameters=None, public=None, vast=None, destination="."):
+    def download(
+        cls,
+        scriptId,
+        section=None,
+        parameters=None,
+        public=None,
+        vast=None,
+        destination=".",
+    ):
         parameters = parameters or {}
 
         try:
